@@ -17,9 +17,8 @@ define([
     'vp_base/js/com/com_util',
     'vp_base/js/com/com_Const',
     'vp_base/js/com/com_String',
-    'vp_base/js/com/component/PopupComponent',
-    'vp_base/js/com/component/DataSelector'
-], function(poHTML, com_util, com_Const, com_String, PopupComponent, DataSelector) {
+    'vp_base/js/com/component/PopupComponent'
+], function(poHTML, com_util, com_Const, com_String, PopupComponent) {
 
     /**
      * PandasOption
